# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AccessRights(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of AccessRights."""

    MANAGE = "Manage"
    """MANAGE."""
    SEND = "Send"
    """SEND."""
    LISTEN = "Listen"
    """LISTEN."""


class CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of entity that created the resource."""

    USER = "User"
    """The entity was created by a user."""
    APPLICATION = "Application"
    """The entity was created by an application."""
    MANAGED_IDENTITY = "ManagedIdentity"
    """The entity was created by a managed identity."""
    KEY = "Key"
    """The entity was created by a key."""


class DefaultAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Default Action for Network Rule Set."""

    ALLOW = "Allow"
    """ALLOW."""
    DENY = "Deny"
    """DENY."""


class EndPointProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the Private Endpoint Connection."""

    CREATING = "Creating"
    """CREATING."""
    UPDATING = "Updating"
    """UPDATING."""
    DELETING = "Deleting"
    """DELETING."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    CANCELED = "Canceled"
    """CANCELED."""
    FAILED = "Failed"
    """FAILED."""


class EntityStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Entity status."""

    ACTIVE = "Active"
    """ACTIVE."""
    DISABLED = "Disabled"
    """DISABLED."""
    RESTORING = "Restoring"
    """RESTORING."""
    SEND_DISABLED = "SendDisabled"
    """SEND_DISABLED."""
    RECEIVE_DISABLED = "ReceiveDisabled"
    """RECEIVE_DISABLED."""
    CREATING = "Creating"
    """CREATING."""
    DELETING = "Deleting"
    """DELETING."""
    RENAMING = "Renaming"
    """RENAMING."""
    UNKNOWN = "Unknown"
    """UNKNOWN."""


class FilterType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Rule filter types."""

    SQL_FILTER = "SqlFilter"
    """SQL_FILTER."""
    CORRELATION_FILTER = "CorrelationFilter"
    """CORRELATION_FILTER."""


class GeoDRRoleType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """GeoDR Role Types."""

    PRIMARY = "Primary"
    """PRIMARY."""
    SECONDARY = "Secondary"
    """SECONDARY."""


class IpAddressType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The IP address type for the namespace. Determines whether the namespace supports IPv4 only or
    both IPv4 and IPv6 (dual stack).
    """

    I_PV4 = "IPv4"
    """The namespace supports IPv4 addresses only."""
    DUAL_STACK = "DualStack"
    """The namespace supports both IPv4 and IPv6 addresses (dual stack)."""


class KeyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The access key to regenerate."""

    PRIMARY_KEY = "PrimaryKey"
    """PRIMARY_KEY."""
    SECONDARY_KEY = "SecondaryKey"
    """SECONDARY_KEY."""


class ManagedServiceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of managed service identity."""

    SYSTEM_ASSIGNED = "SystemAssigned"
    """SYSTEM_ASSIGNED."""
    USER_ASSIGNED = "UserAssigned"
    """USER_ASSIGNED."""
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned, UserAssigned"
    """SYSTEM_ASSIGNED_USER_ASSIGNED."""
    NONE = "None"
    """NONE."""


class MigrationConfigurationName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of MigrationConfigurationName."""

    DEFAULT = "$default"
    """DEFAULT."""


class Mode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Setting to Enable or Disable Confidential Compute."""

    DISABLED = "Disabled"
    """DISABLED."""
    ENABLED = "Enabled"
    """ENABLED."""


class NetworkRuleIPAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The IP Filter Action."""

    ALLOW = "Allow"
    """ALLOW."""


class NetworkSecurityPerimeterConfigurationProvisioningState(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """Provisioning state of NetworkSecurityPerimeter configuration propagation."""

    UNKNOWN = "Unknown"
    """UNKNOWN."""
    CREATING = "Creating"
    """CREATING."""
    UPDATING = "Updating"
    """UPDATING."""
    ACCEPTED = "Accepted"
    """ACCEPTED."""
    INVALID_RESPONSE = "InvalidResponse"
    """INVALID_RESPONSE."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    SUCCEEDED_WITH_ISSUES = "SucceededWithIssues"
    """SUCCEEDED_WITH_ISSUES."""
    FAILED = "Failed"
    """FAILED."""
    DELETING = "Deleting"
    """DELETING."""
    DELETED = "Deleted"
    """DELETED."""
    CANCELED = "Canceled"
    """CANCELED."""


class NspAccessRuleDirection(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Direction of Access Rule."""

    INBOUND = "Inbound"
    """INBOUND."""
    OUTBOUND = "Outbound"
    """OUTBOUND."""


class PrivateLinkConnectionStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status of the connection."""

    PENDING = "Pending"
    """PENDING."""
    APPROVED = "Approved"
    """APPROVED."""
    REJECTED = "Rejected"
    """REJECTED."""
    DISCONNECTED = "Disconnected"
    """DISCONNECTED."""


class ProvisioningStateDR(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the Alias(Disaster Recovery configuration) - possible values 'Accepted'
    or 'Succeeded' or 'Failed'.
    """

    ACCEPTED = "Accepted"
    """ACCEPTED."""
    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    FAILED = "Failed"
    """FAILED."""


class PublicNetworkAccess(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """This determines if traffic is allowed over public network. By default it is enabled."""

    ENABLED = "Enabled"
    """ENABLED."""
    DISABLED = "Disabled"
    """DISABLED."""
    SECURED_BY_PERIMETER = "SecuredByPerimeter"
    """SECURED_BY_PERIMETER."""


class PublicNetworkAccessFlag(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """This determines if traffic is allowed over public network. By default it is enabled."""

    ENABLED = "Enabled"
    """ENABLED."""
    DISABLED = "Disabled"
    """DISABLED."""


class ResourceAssociationAccessMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Access Mode of the resource association."""

    NO_ASSOCIATION_MODE = "NoAssociationMode"
    """NO_ASSOCIATION_MODE."""
    ENFORCED_MODE = "EnforcedMode"
    """ENFORCED_MODE."""
    LEARNING_MODE = "LearningMode"
    """LEARNING_MODE."""
    AUDIT_MODE = "AuditMode"
    """AUDIT_MODE."""
    UNSPECIFIED_MODE = "UnspecifiedMode"
    """UNSPECIFIED_MODE."""


class RoleDisasterRecovery(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """role of namespace in GEO DR - possible values 'Primary' or 'PrimaryNotReplicating' or
    'Secondary'.
    """

    PRIMARY = "Primary"
    """PRIMARY."""
    PRIMARY_NOT_REPLICATING = "PrimaryNotReplicating"
    """PRIMARY_NOT_REPLICATING."""
    SECONDARY = "Secondary"
    """SECONDARY."""


class SkuName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Name of this SKU."""

    BASIC = "Basic"
    """BASIC."""
    STANDARD = "Standard"
    """STANDARD."""
    PREMIUM = "Premium"
    """PREMIUM."""


class SkuTier(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The billing tier of this particular SKU."""

    BASIC = "Basic"
    """BASIC."""
    STANDARD = "Standard"
    """STANDARD."""
    PREMIUM = "Premium"
    """PREMIUM."""


class TlsVersion(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The minimum TLS version for the cluster to support, e.g. '1.3'."""

    ONE0 = "1.0"
    """ONE0."""
    ONE1 = "1.1"
    """ONE1."""
    ONE2 = "1.2"
    """ONE2."""
    ONE3 = "1.3"
    """ONE3."""


class UnavailableReason(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the reason for the unavailability of the service."""

    NONE = "None"
    """NONE."""
    INVALID_NAME = "InvalidName"
    """INVALID_NAME."""
    SUBSCRIPTION_IS_DISABLED = "SubscriptionIsDisabled"
    """SUBSCRIPTION_IS_DISABLED."""
    NAME_IN_USE = "NameInUse"
    """NAME_IN_USE."""
    NAME_IN_LOCKDOWN = "NameInLockdown"
    """NAME_IN_LOCKDOWN."""
    TOO_MANY_NAMESPACE_IN_CURRENT_SUBSCRIPTION = "TooManyNamespaceInCurrentSubscription"
    """TOO_MANY_NAMESPACE_IN_CURRENT_SUBSCRIPTION."""



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------
import unittest
import time

import azure.mgmt.servicebus.models
from azure.mgmt.servicebus.models import (
    SBNamespace,
    SBSku,
    SkuName,
    SBTopic,
    SBSubscription,
    Rule,
    Action,
    SqlFilter,
    FilterType,
    CorrelationFilter,
    SqlRuleAction,
)
from azure.common.credentials import ServicePrincipalCredentials

from devtools_testutils import AzureMgmtTestCase, RandomNameResourceGroupPreparer


class MgmtServiceBusTest(AzureMgmtTestCase):

    def setUp(self):
        super(MgmtServiceBusTest, self).setUp()

        self.servicebus_client = self.create_mgmt_client(azure.mgmt.servicebus.ServiceBusManagementClient)

    @RandomNameResourceGroupPreparer()
    def test_sb_rule_curd(self, resource_group, location):
        # List all topic types
        resource_group_name = resource_group.name  # "ardsouza-resourcemovetest-group2"

        # Create a Namespace
        namespace_name = self.get_replayable_random_resource_name("testingpythontestcaserule")

        namespaceparameter = SBNamespace(
            location=location, tags={"tag1": "value1", "tag2": "value2"}, sku=SBSku(name=SkuName.standard)
        )
        creatednamespace = self.servicebus_client.namespaces.create_or_update(
            resource_group_name, namespace_name, namespaceparameter
        ).result()
        self.assertEqual(creatednamespace.name, namespace_name)

        while (
            self.servicebus_client.namespaces.get(resource_group_name, namespace_name).provisioning_state != "Succeeded"
        ):
            if self.is_live:
                time.sleep(15)
            continue

        # Create a Topic
        topic_name = self.get_replayable_random_resource_name("testingpythonsdktopic")
        createtopicresponse = self.servicebus_client.topics.create_or_update(
            resource_group_name, namespace_name, topic_name, SBTopic()
        )
        self.assertEqual(createtopicresponse.name, topic_name)

        # Get the created Topic
        gettopicresponse = self.servicebus_client.topics.get(resource_group_name, namespace_name, topic_name)
        self.assertEqual(gettopicresponse.name, topic_name)

        # Create subscription
        subscription_name = self.get_replayable_random_resource_name("testingpythonsdksubscription")
        createsubscriptionresponse = self.servicebus_client.subscriptions.create_or_update(
            resource_group_name, namespace_name, topic_name, subscription_name, SBSubscription()
        )
        self.assertEqual(createsubscriptionresponse.name, subscription_name)

        # Get created subscription
        getsubscriptionresponse = self.servicebus_client.subscriptions.get(
            resource_group_name, namespace_name, topic_name, subscription_name
        )
        self.assertEqual(getsubscriptionresponse.name, subscription_name)

        # create rule
        rule_name = self.get_replayable_random_resource_name("testingpythonsdkrule")
        createruleresponse = self.servicebus_client.rules.create_or_update(
            resource_group_name, namespace_name, topic_name, subscription_name, rule_name, Rule()
        )
        self.assertEqual(createruleresponse.name, rule_name)

        # get create rule
        getruleresponse = self.servicebus_client.rules.get(
            resource_group_name, namespace_name, topic_name, subscription_name, rule_name
        )
        self.assertEqual(getruleresponse.name, rule_name)

        # get all rules
        getallrulesresponse = list(
            self.servicebus_client.rules.list_by_subscriptions(
                resource_group_name, namespace_name, topic_name, subscription_name
            )
        )
        self.assertEqual(len(getallrulesresponse), 1)

        # update create rule with filter and action
        strSqlExp = "myproperty='test'"
        ruleparameter = Rule(
            action=None,
            filter_type=FilterType.sql_filter,
            sql_filter=SqlFilter(sql_expression=strSqlExp),
            correlation_filter=None,
        )
        createruleresponse = self.servicebus_client.rules.create_or_update(
            resource_group_name, namespace_name, topic_name, subscription_name, rule_name, ruleparameter
        )
        self.assertEqual(createruleresponse.name, rule_name)

        # Delete the created subscription
        self.servicebus_client.subscriptions.delete(resource_group_name, namespace_name, topic_name, subscription_name)

        # delete the Topic
        self.servicebus_client.topics.delete(resource_group_name, namespace_name, topic_name)

        # Delete the create namespace
        deletenamespace = self.servicebus_client.namespaces.delete(resource_group_name, namespace_name).result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------
import unittest
import time

import azure.mgmt.servicebus.models
from azure.mgmt.servicebus.models import (
    SBNamespace,
    SBSku,
    SkuName,
    SBTopic,
    SBAuthorizationRule,
    AccessRights,
    AccessKeys,
)
from azure.common.credentials import ServicePrincipalCredentials

from devtools_testutils import AzureMgmtTestCase, RandomNameResourceGroupPreparer


class MgmtServiceBusTest(AzureMgmtTestCase):

    def setUp(self):
        super(MgmtServiceBusTest, self).setUp()

        self.servicebus_client = self.create_mgmt_client(azure.mgmt.servicebus.ServiceBusManagementClient)

    @RandomNameResourceGroupPreparer()
    def test_sb_topic_curd(self, resource_group, location):
        # List all topic types
        resource_group_name = resource_group.name  # "ardsouza-resourcemovetest-group2"

        # Create a Namespace
        namespace_name = self.get_replayable_random_resource_name("testingpythontestcasetopic")

        namespaceparameter = SBNamespace(
            location=location, tags={"tag1": "value1", "tag2": "value2"}, sku=SBSku(name=SkuName.standard)
        )
        creatednamespace = self.servicebus_client.namespaces.create_or_update(
            resource_group_name, namespace_name, namespaceparameter
        ).result()
        self.assertEqual(creatednamespace.name, namespace_name)

        while (
            self.servicebus_client.namespaces.get(resource_group_name, namespace_name).provisioning_state != "Succeeded"
        ):
            if self.is_live:
                time.sleep(15)
            continue

        # Create a Topic
        topic_name = self.get_replayable_random_resource_name("testingpythonsdktopic")
        createtopicresponse = self.servicebus_client.topics.create_or_update(
            resource_group_name, namespace_name, topic_name, SBTopic()
        )
        self.assertEqual(createtopicresponse.name, topic_name)

        # Get the created Topic
        gettopicresponse = self.servicebus_client.topics.get(resource_group_name, namespace_name, topic_name)
        self.assertEqual(gettopicresponse.name, topic_name)

        # Get all the topics
        listbynamespacetopicresponse = list(
            self.servicebus_client.topics.list_by_namespace(resource_group_name, namespace_name)
        )
        self.assertEqual(len(listbynamespacetopicresponse), 1)
        self.assertEqual(listbynamespacetopicresponse[0].name, topic_name)

        # update topic
        updatetopicresponse = self.servicebus_client.topics.create_or_update(
            resource_group_name,
            namespace_name,
            topic_name,
            SBTopic(enable_express=True, enable_batched_operations=True, max_size_in_megabytes=1024),
        )
        self.assertEqual(updatetopicresponse.name, topic_name)
        self.assertEqual(updatetopicresponse.enable_batched_operations, True)
        self.assertEqual(updatetopicresponse.max_size_in_megabytes, 1024)
        self.assertEqual(updatetopicresponse.enable_express, True)

        # Create a new authorizationrule
        authoRule_name = self.get_replayable_random_resource_name("testingauthrulepy")
        createtopicauthorule = self.servicebus_client.topics.create_or_update_authorization_rule(
            resource_group_name,
            namespace_name,
            topic_name,
            authoRule_name,
            [AccessRights("Send"), AccessRights("Listen")],
        )
        self.assertEqual(
            createtopicauthorule.name,
            authoRule_name,
            "Authorization rule name not as created - create_or_update_authorization_rule ",
        )
        self.assertEqual(len(createtopicauthorule.rights), 2)

        # Get the created authorizationrule
        gettopicauthorule = self.servicebus_client.topics.get_authorization_rule(
            resource_group_name, namespace_name, topic_name, authoRule_name
        )
        self.assertEqual(
            gettopicauthorule.name,
            authoRule_name,
            "Authorization rule name not as passed as parameter - get_authorization_rule",
        )
        self.assertEqual(
            len(gettopicauthorule.rights), 2, "Access rights mis match as created  - get_authorization_rule "
        )

        # update the rights of the authorizatiorule
        gettopicauthorule.rights.append("Manage")
        updatetopicauthorule = self.servicebus_client.topics.create_or_update_authorization_rule(
            resource_group_name, namespace_name, topic_name, authoRule_name, gettopicauthorule.rights
        )
        self.assertEqual(
            updatetopicauthorule.name,
            authoRule_name,
            "Authorization rule name not as passed as parameter for update call - create_or_update_authorization_rule ",
        )
        self.assertEqual(
            len(updatetopicauthorule.rights),
            3,
            "Access rights mis match as updated  - create_or_update_authorization_rule ",
        )

        # list all the authorization ruels for the given Topic
        listtopicauthorule = list(
            self.servicebus_client.topics.list_authorization_rules(resource_group_name, namespace_name, topic_name)
        )
        self.assertEqual(
            len(listtopicauthorule), 1, "number of authorization rule mismatch, created = 1 - list_authorization_rules"
        )

        # List keys for the authorization rule
        listkeysauthorizationrule = self.servicebus_client.topics.list_keys(
            resource_group_name, namespace_name, topic_name, authoRule_name
        )
        self.assertIsNotNone(listkeysauthorizationrule)

        # regenerate Keys for authorizationrule - Primary
        regenratePrimarykeyauthorizationrule = self.servicebus_client.topics.regenerate_keys(
            resource_group_name, namespace_name, topic_name, authoRule_name, "PrimaryKey"
        )
        self.assertNotEqual(listkeysauthorizationrule.primary_key, regenratePrimarykeyauthorizationrule.primary_key)

        # regenerate Keys for authorizationrule - Primary
        regenrateSecondarykeyauthorizationrule = self.servicebus_client.topics.regenerate_keys(
            resource_group_name, namespace_name, topic_name, authoRule_name, "SecondaryKey"
        )
        self.assertNotEqual(
            listkeysauthorizationrule.secondary_key, regenrateSecondarykeyauthorizationrule.secondary_key
        )

        # delete the authorizationrule
        self.servicebus_client.topics.delete_authorization_rule(
            resource_group_name, namespace_name, topic_name, authoRule_name
        )

        # list all the authorization ruels for the given Topic
        listtopicauthorule = list(
            self.servicebus_client.topics.list_authorization_rules(resource_group_name, namespace_name, topic_name)
        )
        lenTemp = len(listtopicauthorule)

        # delete the Topic
        self.servicebus_client.topics.delete(resource_group_name, namespace_name, topic_name)

        # Delete the create namespace
        deletenamespace = self.servicebus_client.namespaces.delete(resource_group_name, namespace_name).result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()
